Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Amount ¶
type Amount struct {
// Amount in the selected currency, in the form of a string with a dot separator,
// for example, 10.00.
Value string `json:"value,omitempty"`
// Three-letter currency code in the ISO-4217 format. Example: RUB.
Currency string `json:"currency,omitempty"`
}
Amount of Payment. Sometimes YooMoney's partners charge additional commission from the users that is not included in this amount.
type CancellationDetails ¶
type CancellationDetails struct {
// The participant of the payment process that
// made the decision to cancel the payment. Possible values are yoo_money,
// payment_network, and merchant.
Party string `json:"party,omitempty"`
// Reason behind the cancelation.
Reason string `json:"reason,omitempty"`
}
Commentary to the canceled status: who and why canceled the payment.
type Item ¶
type Item struct {
// parameter with the name of the product or service
Description string `json:"description"`
// parameter with the amount per unit of product
Quantity string `json:"quantity"`
// parameter specifying the quantity of goods (only integers, for example 1)
Amount *Amount `json:"amount"`
// parameter with the fixed value 1 (price without VAT)
VatCode string `json:"vat_code"`
PaymentSubject string `json:"payment_subject,omitempty"`
PaymentMode string `json:"payment_mode,omitempty"`
}
type Settlement ¶
type Settlement struct {
// Transaction type. Fixed value: payout — payout to seller.
Type string `json:"type,omitempty"`
// Amount of seller’s remuneration.
Amount Amount `json:"amount,omitempty"`
}
Information about money distribution.
Click to show internal directories.
Click to hide internal directories.