yoopayout

package
v0.0.0-...-b7a9590 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package yoopayout describes all the necessary entities for working with YooMoney Payouts.

Package yoopayout describes all the necessary entities for working with YooMoney Payouts.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Amount

type Amount struct {
	Value    string `json:"value"`
	Currency string `json:"currency"`
}

type Metadata

type Metadata struct {
	OrderId string `json:"order_id"`
}

type Payout

type Payout struct {
	Id                    string                `json:"id"`
	Amount                *yoocommon.Amount     `json:"amount"`
	PayoutDestinationData PayoutDestinationData `json:"payout_destination_data"`
	Description           string                `json:"description"`
	Metadata              Metadata              `json:"metadata"`
	CreatedAt             string                `json:"created_at"`
	Status                Status                `json:"status"`
	Test                  bool                  `json:"test"`
}

type PayoutBalance

type PayoutBalance struct {
	// Amount in the selected currency.
	// Expressed as a string and written with a period, for example 10.00.
	// The number of characters after the dot depends on the selected currency.
	Value string `json:"value,omitempty"`

	// Three-letter currency code in ISO-4217 format.
	// Example: RUB. Must match the subaccount currency (recipient.gateway_id) if you separate payment flows,
	// and the account currency (shopId in your account) if you don't.
	Currency string `json:"currency,omitempty"`
}

The balance of your gateway.

type PayoutDestinationData

type PayoutDestinationData struct {
	Type   PayoutMethodType `json:"type"`
	Phone  string           `json:"phone"`
	BankId string           `json:"bank_id"`
}

type PayoutMethodType

type PayoutMethodType string
const (
	// Payments to bank cards.
	PayoutTypeBankCard PayoutMethodType = "bank_card"
	// Payments to YooMoney wallets.
	PaymentTypeYooMoney PayoutMethodType = "yoo_money"
	// Payments via SBP.
	PayoutTypeSBP PayoutMethodType = "sbp"
)

type SbpBank

type SbpBank struct {
	BankId string `json:"bank_id"`
	Name   string `json:"name"`
	Bic    string `json:"bic"`
}

type SbpBankList

type SbpBankList struct {
	Type  string    `json:"type"` // possible value: list
	Items []SbpBank `json:"items"`
}

type Status

type Status string
const (
	Pending   Status = "pending"
	Succeeded Status = "succeeded"
	Canceled  Status = "canceled"
)

Jump to