yoosettings

package
v0.0.0-...-d4840ec Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package yoosettings describes all the necessary entities for working with YooMoney Settings.

Package yoosettings describes all the necessary entities for working with YooMoney Settings.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Settings

type Settings struct {
	// Store's or gateway's ID in YooMoney.
	AccountId string `json:"account_id,omitempty"`

	// Store's or gateway status.
	Status *Status `json:"status,omitempty"`

	// This is the Demo store or gateway.
	Test bool `json:"test,omitempty"`

	// Sending receipts enabled in store's or gateway's settings.
	FiscalizationEnabled bool `json:"fiscalization_enabled,omitempty"`

	// List of payment methods available to a store or gateway.
	PaymentMethods []yoopayment.PaymentMethoder `json:"payment_methods,omitempty"`

	// Store's INN (TIN): 10 or 12 digits.
	ITN string `json:"itn,omitempty"`

	// List of payout methods available to the gateway.
	PayoutMethods *[]yoopayout.PayoutMethodType `json:"payout_methods,omitempty"`

	// The name of the gateway, which is displayed in the YuKassa personal account.
	// Present if you requested gateway settings.
	Name string `json:"name,omitempty"`

	// The balance of your gateway. Present if you requested gateway settings.
	PayoutBalance *yoopayout.PayoutBalance `json:"payout_balance,omitempty"`
}

Settings object contains relevant information about the configuration of the store or gateway.

type Status

type Status string
const (
	// Enabled – store is signed up for YooMoney and it can accept payments.
	Enabled Status = "enabled"

	// Disabled – store can't accept payments (not signed up yet, closed, or temporarily unavailable).
	Disabled Status = "disabled"
)

Jump to